quadmompy.equations package
===========================

Submodules
----------

quadmompy.equations.fpe\_1d module
----------------------------------

.. automodule:: quadmompy.equations.fpe_1d
   :members:
   :undoc-members:
   :show-inheritance:

quadmompy.equations.integrate\_1d module
----------------------------------------

.. automodule:: quadmompy.equations.integrate_1d
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: quadmompy.equations
   :members:
   :undoc-members:
   :show-inheritance:
